@@ -27,6 +27,7 @@
 
 import datetime
 import hubzero.config.passwords
+import hubzero.utilities.group
 import hubzero.utilities.misc
 import hubzero.config.webconfig
 import hubzero.data.db
@@ -137,65 +138,6 @@ def _insert_jos_users_password(db, userid, pw):
 	db.execQuery(sql, data)
 
 
-def _insert_jos_xgroups(db, name, description):
-	sql =  "INSERT INTO jos_xgroups ( `cn`, `description`, `published`, `type`, `access`, `public_desc`, `private_desc`, `restrict_msg`, "
-	sql += "`join_policy`, `privacy`, `discussion_email_autosubscribe`, `logo`, `overview_type`, `overview_content`, `plugins`, `created`,"
-	sql += "`created_by`, `params`) " 
-	sql += "VALUES (" + '%s,'*17 + "%s );" 
-
-	data = (name, description, 0, 1, 0, '', '', '',   1, 1, 0, '', None, None, None, datetime.datetime.now(), None, None)
-	gidNumber = db.execInsertQuery(sql, data)
-	return gidNumber
-
-
-def _insert_jos_xgroups_memers(db, gidNumber, uidNumber):
-	sql =  "INSERT INTO jos_xgroups ( gidNumber, uidNumber "
-	sql += "VALUES ( %s, %s );" 
-
-	data = (gidNumber, uidNumber)
-	gidNumber = db.execQuery(sql, data)
-
-
-def _del_jos_xgroups(db, name):
-	sql = "DELETE FROM jos_xgroups WHERE `CN`=%s "
-	data = (name)
-	db.execQuery(sql, data)
-
-
-def _add_ldap_group(groupName, groupDescription, gidNumber):
-	hubLDAPAcctMgrPW = hubzero.config.webconfig.getWebConfigOption("hubLDAPAcctMgrPW")	
-	hubLDAPAcctMgrDN = hubzero.config.webconfig.getWebConfigOption("hubLDAPAcctMgrDN")	
-	hubLDAPBaseDN = hubzero.config.webconfig.getWebConfigOption("hubLDAPBaseDN")
-
-	l = ldap.open("localhost")
-	l.simple_bind_s(hubLDAPAcctMgrDN, hubLDAPAcctMgrPW)
-	
-	dn = "cn=" + groupName + ",ou=groups," + hubLDAPBaseDN
-	attrs = {}
-	attrs['objectclass'] = ['posixGroup', 'top']
-	attrs['cn'] = groupName
-	attrs['gidNumber'] =str( gidNumber)
-	attrs['description'] = groupDescription
-	#attrs['ou'] = 'users'
-	ldif = ldap.modlist.addModlist(attrs)
-	print ldif
-	l.add_s(dn, ldif)
-
-
-def _del_ldap_group(groupName):
-	# get ldapManagerUserDN and PW
-	hubLDAPAcctMgrPW = hubzero.config.webconfig.getWebConfigOption("hubLDAPAcctMgrPW")	
-	hubLDAPAcctMgrDN = hubzero.config.webconfig.getWebConfigOption("hubLDAPAcctMgrDN")	
-	hubLDAPBaseDN = hubzero.config.webconfig.getWebConfigOption("hubLDAPBaseDN")
-
-	l = ldap.open("localhost")
-	l.simple_bind_s(hubLDAPAcctMgrDN, hubLDAPAcctMgrPW)
-
-	dn = "cn=" + groupName + ",ou=groups," + hubLDAPBaseDN
-	print dn
-	l.delete_s(dn)
-
-
 def _add_ldap_user(username, password, uidNumber, homeDir):
 
 	# get ldapManagerUserDN and PW
@@ -227,30 +169,17 @@ def _add_ldap_user(username, password, uidNumber, homeDir):
 
 def _delete_ldap_user(username):
 	# get ldapManagerUserDN and PW
-	hubLDAPAcctMgrPW = hubzero.config.webconfig.getWebConfigOption("hubLDAPAcctMgrPW")	
-	hubLDAPAcctMgrDN = hubzero.config.webconfig.getWebConfigOption("hubLDAPAcctMgrDN")	
-	hubLDAPBaseDN = hubzero.config.webconfig.getWebConfigOption("hubLDAPBaseDN")
+	hubLDAPAcctMgrDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerdn")
+	hubLDAPAcctMgrPW= hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerpw")
+	hubLDAPBaseDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_basedn")	
 
 	l = ldap.open("localhost")
 	l.simple_bind_s(hubLDAPAcctMgrDN, hubLDAPAcctMgrPW)
-
-	dn = "cn=" + username + "," + hubLDAPBaseDN
+	dn = "uid=" + username + ",ou=users," + hubLDAPBaseDN
+	print "delete ldap user dn: " + dn
 	l.delete_s(dn)
 
 
-def delhubgroup(groupName):
-	# grab config options
-	dbPW = hubzero.config.passwords.getMySqlPW()
-	db =  hubzero.data.db.mySql("localhost", "myhub", "myhub", dbPW)
-	_del_ldap_group(groupName)
-	_del_jos_xgroups(db, groupName)
-
-
-def addhubgroup(db, groupName, groupDescription):
-	gidNumber = _insert_jos_xgroups(db, groupName, groupDescription)
-	return gidNumber
-
-		 
 def addhubuser(hubname, username, fname, mname, lname, email, pw, pwdisabled, joomlagid, 
                joomlagidNumber, gid, gidNumber, joomlauserid, loginShell, nocreatehome, homeDir, createGroup, 
                skipldap):
@@ -287,7 +216,7 @@ def addhubuser(hubname, username, fname, mname, lname, email, pw, pwdisabled, jo
 		if rc:
 			print procStdErr
 		gidNumber = _insert_jos_xgroups(db, name, description)	
-		_insert_jos_xgroups_memers(gidNumber, userID)
+		hubzero.utilities.group._insert_jos_xgroups_members(gidNumber, userID)
 		
 
 	# create home directory
